.. :changelog:

Changelog
---------

0.2.2 2015-04-18
================
* Added a forget method to unlearn a text from a class

0.2.0 2015-04-18
================
* Python 3 compatibility
* Added a Pythonic wrapper with a potentially pluggable storage backend
* Support for dumping control block/data block to string instead of file
* Added basic tests

0.1.0 2015-04-10
================
* Initial import from `pmundkur/libcrm114 <https://github.com/pmundkur/libcrm114>`_






